@@ -25,11 +25,12 @@ def get_settings(reload=False, file="~/.machinable/settings.yaml"):
                 {
                     "cache": {"imports": False},
                     "imports": {},
-                    "schema_validation": False,
+                    "schema_validation": True,
                     "tmp_directory": "userdata://machinable:machinable/tmp",
                     "default_storage": {"url": "mem://"},
                     "default_engine": None,
                     "default_index": None,
+                    "default_project": None,
                     "default_code_backup": None,
                 },
                 _settings,
