@@ -43,7 +43,8 @@ class Log:
         )
         fileh.setFormatter(
             logging.Formatter(
-                "%(asctime)s; %(levelname)s: %(message)s", datefmt="%Y-%m-%d %H:%M:%S"
+                "%(asctime)s; %(levelname)s: %(message)s",
+                datefmt="%Y-%m-%d %H:%M:%S",
             )
         )
 
